@@ -5,9 +5,12 @@ from pydantic import BaseModel
 MODEL_TYPE = 'languages'
 
 
-class APILanguagesFields(BaseModel):
-    full_name: Optional[str] = None
+class CreateAPILanguagesFields(BaseModel):
     language: Optional[str] = None
+    is_primary_language: Optional[bool] = None
+
+
+class APILanguagesFields(CreateAPILanguagesFields):
+    full_name: Optional[str] = None
     language_dropdown: Optional[str] = None
     language_other: Optional[str] = None
-    is_primary_language: Optional[bool] = None
