@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Union
 
 from pydantic import BaseModel
 
@@ -28,3 +28,11 @@ class APIPartnerData(response_models.APIData):
 
 class ListAPIPartnerData(BaseModel):
     __root__: list[APIPartnerData]
+
+
+class APIPartnerResponse(response_models.APIResponse):
+    data: APIPartnerData
+
+
+class ListAPIPartnerResponse(response_models.ListAPIResponse):
+    data: list[Union[APIPartnerData, dict]]
\ No newline at end of file
